--  Licensed Materials - Property of IBM
--  (c) Copyright IBM Corp. 2002, 2004
--  US Government Users Restricted Rights - Use, duplication or disclosure 
--  restricted by GSA ADP Schedule Contract with IBM Corp. 
 
-- ====================================================================
--	NAME		Create_ItemSync_Tables.sql
--
--	DESCRIPTION	DB2 sql script to create the PROCESSED_GTIN
--                      and the AUDIT_LOG tables in the Item Sync
--			database.
--
--   	PROCESSED_GTIN Table
--
-- 		GTIN		- Global Trade Item Number
--		FROMGLN		- Supplier's GLN 
--		TARGMRKT	- Target Market
--		DTCREATE	- Creation date
--		DTUPDATE	- Update date
--		COMMAND		- The last command processed for the gtin
--		STATE		- The state of the gtin (REGISTERED)
--		STATUS		- The status of the command (SENT, Success, Failure)
--		ERRCODE		- Error code if status is Failure
--		ERRDATA		- Error description if status is Failure
--
--   	AUDIT_LOG Table
--
--		MSGID		- Unique message ID
-- 		GTIN		- Global Trade Item Number
--		FROMGLN		- Supplier's GLN 
--		TARGMRKT	- Target Market
--		TOGLN		- The publish to GLN
--		DTCREATE	- Creation date
--		DTUPDATE	- Update date
--		COMMAND		- The command/response being processed for the gtin
--		STATE		- The state of the gtin (REGISTERED)
--		STATUS		- The status of the command (SENT, Success, Failure)
--		ERRCODE		- Error code if status is Failure
--		ERRDATA		- Error description if status is Failure
--		PRICEID		- ID to correlate price and price bracket
--
-- ==================================================================== 
 
DROP TABLE PROCESSED_GTIN
DROP TABLE AUDIT_LOG


CREATE TABLE PROCESSED_GTIN (GTIN varchar(32) not null, FROMGLN varchar(32) not null, TARGMRKT varchar(32) not null, DTCREATE varchar(32), DTUPDATE varchar(32), COMMAND varchar(64), STATE varchar(32), STATUS varchar(32), ERRCODE varchar(32), ERRDATA varchar(1024))

CREATE TABLE AUDIT_LOG (MSGID varchar(128), GTIN varchar(32), FROMGLN varchar(32), TARGMRKT varchar(32), TOGLN varchar(32), DTCREATE varchar(32), DTUPDATE varchar(32), COMMAND varchar(64), STATE varchar(32), STATUS varchar(32), ERRCODE varchar(32), ERRDATA varchar(1024), PRICEID varchar(128))
