--  Licensed Materials - Property of IBM
--  (c) Copyright IBM Corp. 2002, 2004
--  US Government Users Restricted Rights - Use, duplication or disclosure 
--  restricted by GSA ADP Schedule Contract with IBM Corp. 
--
-- ====================================================================
--	NAME		Create_ItemSync_Tables.sql
--
--	DESCRIPTION	SQL Server sql script to create AUDIT_LOG and
--			PROCESSED_GTIN tables and associated objects within 
--			the ItemSync database.
--
--
--	PROCESSED_GTIN Table
--
--	        GTIN - tradeItem.tradeItemIdentification.gtin
-- 		FROMGLN - Retail_Item.glnList.FromGln
-- 		TARGMRKT - tradeItem.tradeItemInformation.targetMarketInformation[0].targetMarketCountryCode
-- 		DTCREATE - timestamp of RCIR_ADD message
-- 		DTUPDATE- timestamp for any modification to this gtin, including response
-- 		COMMAND- can be ADD, CHANGE, or CORRECT (derived from notificationTopic.topic)
-- 		STATE - REGISTERED or blank (set to REGISTERED upon successful response from UCCnet)
-- 		STATUS - SENT,SUCCESS,FAILED
-- 		ERRCODE-  Error code returned from UCCnet
-- 		ERRDATA - short descriptive message of error 
--
--	AUDIT_LOG Table
--
--		MSGID - transaction ID ( can be used to match commands to the response
--	        GTIN - tradeItem.tradeItemIdentification.gtin
-- 		FROMGLN - Retail_Item.glnList.FromGln
-- 		TARGMRKT - tradeItem.tradeItemInformation.targetMarketInformation[0].targetMarketCountryCode
--		TOGLN - dataRecipient gln for publication messages
-- 		DTCREATE - timestamp of RCIR_ADD message
-- 		DTUPDATE- timestamp for any modification to this gtin, including response
-- 		COMMAND- can be ADD, CHANGE, or CORRECT (derived from notificationTopic.topic)
-- 		STATE - REGISTERED or blank (set to REGISTERED upon successful response from UCCnet)
-- 		STATUS - SENT,SUCCESS,FAILED
-- 		ERRCODE-  Error code returned from UCCnet
-- 		ERRDATA - short descriptive message of error 
-- 		PRICEID - Unique price/price bracket correlation ID
--
-- ====================================================================

SET QUOTED_IDENTIFIER ON
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
SET ARITHABORT ON
SET NUMERIC_ROUNDABORT OFF
SET CONCAT_NULL_YIELDS_NULL ON
SET ANSI_NULLS ON
SET ANSI_PADDING ON
SET ANSI_WARNINGS ON
BEGIN TRANSACTION

create table PROCESSED_GTIN (
	GTIN varchar(32) not null,
	FROMGLN varchar(32) not null,
	TARGMRKT varchar(32) not null,
	DTCREATE varchar(32), 
	DTUPDATE varchar(32), 
	COMMAND varchar(64), 
	STATE varchar(32), 
	STATUS varchar(32), 
	ERRCODE varchar(32), 
	ERRDATA varchar(1024)
) 

GO
create table PROCESSED_GTIN_rep (
	GTIN varchar(32) not null,
	FROMGLN varchar(32) not null,
	TARGMRKT varchar(32) not null,
	DTCREATE varchar(32), 
	DTUPDATE varchar(32), 
	COMMAND varchar(64), 
	STATE varchar(32), 
	STATUS varchar(32), 
	ERRCODE varchar(32), 
	ERRDATA varchar(1024)
) 

GO
create table AUDIT_LOG(
	MSGID varchar(128),
	GTIN varchar(32),
	FROMGLN varchar(32),
	TARGMRKT varchar(32),
	TOGLN varchar(32),
	DTCREATE varchar(32), 
	DTUPDATE varchar(32), 
	COMMAND varchar(64), 
	STATE varchar(32), 
	STATUS varchar(32), 
	ERRCODE varchar(32), 
	ERRDATA varchar(1024),
	PRICEID varchar(128)
) 
GO
create table AUDIT_LOG_rep(
	MSGID varchar(128),
	GTIN varchar(32),
	FROMGLN varchar(32),
	TARGMRKT varchar(32),
	TOGLN varchar(32),
	DTCREATE varchar(32), 
	DTUPDATE varchar(32), 
	COMMAND varchar(64), 
	STATE varchar(32), 
	STATUS varchar(32), 
	ERRCODE varchar(32), 
	ERRDATA varchar(1024),
	PRICEID varchar(128)
	
) 
GO

COMMIT
