--  Licensed Materials - Property of IBM
--  (c) Copyright IBM Corp. 2002, 2004
--  US Government Users Restricted Rights - Use, duplication or disclosure 
--  restricted by GSA ADP Schedule Contract with IBM Corp. 
--
-- ====================================================================
--	NAME		Create_ItemSync_Tables.sql
--
--	SYNOPSIS	c:/> sqlplus crossworlds/admin@cwld @AUDIT_LOG
--
--	DESCRIPTION	Oracle sql script to create the PROCESSED_GTIN
--                      and the AUDIT_LOG tables in the Item Sync
--			database.
--
--
--	PROCESSED_GTIN Table
--
--	        GTIN - tradeItem.tradeItemIdentification.gtin
-- 		FROMGLN - Retail_Item.glnList.FromGln
-- 		TARGMRKT - tradeItem.tradeItemInformation.targetMarketInformation[0].targetMarketCountryCode
-- 		DTCREATE - timestamp of RCIR_ADD message
-- 		DTUPDATE- timestamp for any modification to this gtin, including response
-- 		COMMAND- can be ADD, CHANGE, or CORRECT (derived from notificationTopic.topic)
-- 		STATE - REGISTERED or blank (set to REGISTERED upon successful response from UCCnet)
-- 		STATUS - SENT,SUCCESS,FAILED
-- 		ERRCODE-  Error code returned from UCCnet
-- 		ERRDATA - short descriptive message of error 
--
--	AUDIT_LOG Table
--
--		MSGID - transaction ID ( can be used to match commands to the response
--	        GTIN - tradeItem.tradeItemIdentification.gtin
-- 		FROMGLN - Retail_Item.glnList.FromGln
-- 		TARGMRKT - tradeItem.tradeItemInformation.targetMarketInformation[0].targetMarketCountryCode
--		TOGLN - dataRecipient gln for publication messages
-- 		DTCREATE - timestamp of RCIR_ADD message
-- 		DTUPDATE- timestamp for any modification to this gtin, including response
-- 		COMMAND- can be ADD, CHANGE, or CORRECT (derived from notificationTopic.topic)
-- 		STATE - REGISTERED or blank (set to REGISTERED upon successful response from UCCnet)
-- 		STATUS - SENT,SUCCESS,FAILED
-- 		ERRCODE-  Error code returned from UCCnet
-- 		ERRDATA - short descriptive message of error 
-- 		PRICEID - Unique price/price bracket correlation ID
--
-- ====================================================================
-- enable dbms_output
set serveroutput on

-- create PROCESSED_GTIN table
drop table PROCESSED_GTIN;
create table PROCESSED_GTIN (
	GTIN varchar2(32) not null, 
	FROMGLN varchar2(32) not null, 
	TARGMRKT varchar2(32) not null, 
	DTCREATE varchar2(32), 
	DTUPDATE varchar2(32), 
	COMMAND varchar2(64), 
	STATE varchar2(32), 
	STATUS varchar2(32), 
	ERRCODE varchar2(32), 
	ERRDATA varchar2(1024)
);

-- create AUDIT_LOG table
drop table AUDIT_LOG;
create table AUDIT_LOG (
	MSGID varchar2(128),
	GTIN varchar2(32), 
	FROMGLN varchar2(32), 
	TARGMRKT varchar2(32), 
	TOGLN varchar2(32),
	DTCREATE varchar2(32), 
	DTUPDATE varchar2(32), 
	COMMAND varchar2(64), 
	STATE varchar2(32), 
	STATUS varchar2(32), 
	ERRCODE varchar2(32), 
	ERRDATA varchar2(1024),
	PRICEID varchar2(128)
);
